==> nextcloud-app-contacts-2.1.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/sl.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Stiki",
    "Download" : "Prejmi",
    "Copy link" : "Kopiraj povezavo",
    "Click to copy the link to your clipboard" : "Klikni, da kopiraš povezavo na tvoje odlagališče",
    "Toggle sharing" : "Preklopi deljenje",
    "Delete" : "Pobriši",
    "Rename" : "Preimenuj",
    "Share with users or groups" : "Deli z uporabniki ali skupinami",
    "can edit" : "lahko ureja",
    "Close" : "Zapri",
    "Enabled" : "Omogočeno",
    "Disabled" : "Onemogočeno",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Ni podprto!",
    "Press ⌘-C to copy." : "Pritisni ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisni Ctrl-C za kopiranje.",
    "Address book name" : "Ime imenika",
    "Only these special characters are allowed: -_.!?#|()" : "Dovoljeni so le sledeči posebni znaki: -_.!?#|()",
    "Address book could not be created." : "Imenika ni mogoče ustvariti.",
    "Upload new image" : "Naloži novo sliko",
    "The selected image is too big (max 1MB)" : "Izbrana slika je prevelika (omejitev je 1 MB).",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Ta kartica je počkodovana in je bila popravljena. Preveri podatke in shrani, da bodo spremembe trajne.",
    "No contacts in here" : "Ni dodanega nobenega stika!",
    "Name" : "Ime",
    "Organization" : "Ustanova",
    "Title" : "Naziv/funkcija",
    "Add field …" : "Dodaj polje",
    "Save changes" : "Shrani spremembe",
    "Address book" : "Imenik",
    "Loading contacts …" : "Nalaganje stikov ...",
    "Import into" : "Uvozi v",
    "Importing..." : "Uvažanje ...",
    "Select your addressbook" : "Izberi imenik",
    "Import is disabled because no writable address book had been found." : "Uvoz je onemogočen! Ni mogoče najti zapisljivega imenika.",
    "No search result for {query}" : "Ni zadetkov iskanja za {query}",
    "All contacts" : "Vsi stiki",
    "Post office box" : "Poštni predal",
    "Postal code" : "Poštna številka",
    "City" : "Mesto",
    "State or province" : "Zvezna država ali provinca",
    "Country" : "Država",
    "Address" : "Naslov",
    "(new group)" : "(nova skupina)",
    "Last name" : "Priimek",
    "First name" : "Ime",
    "Additional names" : "Druga imena",
    "Prefix" : "Predpona",
    "Suffix" : "Pripona",
    "Importing into" : "Uvažanje informacij",
    "New contact" : "Nov stik",
    "Not grouped" : "Brez skupine",
    "Sort by" : "Uredi po",
    "There is no address book available to create a contact." : "Za ustvarjanje stika ni na voljo nobenega imenika",
    "{addressbook} shared by {owner}" : "Souporabo imenika {addressbook} je omogočil uporabnik {owner}",
    "Contact not found." : "Stika ne najdem.",
    "You don't have permission to write to this addressbook." : "Nimate dovoljenja za zapisovanje v imenik",
    "Contact could not be created." : "Stika ni mogoče ustvariti.",
    "No contacts in file. Only vCard files are allowed." : "V datoteki ni stikov. Dovoljene so samo vCard datoteke.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Podprti sta le različici vCard 4.0 (RFC6350) in vCard 3.0 (RFC2426).",
    "Contact could not be moved." : "Stika ni mogoče premakniti",
    "Contact could not be saved." : "Stikov ne morem shraniti.",
    "Waiting for the server to be ready…" : "Čakanje na strežnik ...",
    "Importing…" : "Uvažanje",
    "Display name" : "Prikaži ime",
    "Nickname" : "Vzdevek",
    "Detailed name" : "Podrobno ime",
    "Notes" : "Zapiski",
    "Website" : "Spletna stran",
    "Federated Cloud ID" : "ID zveznega oblaka",
    "Home" : "Domači naslov",
    "Work" : "Službeni naslov",
    "Other" : "Drugo",
    "Groups" : "Skupine",
    "Birthday" : "Rojstni dan",
    "Anniversary" : "Obletnica",
    "Date of death" : "Datum smrti",
    "Email" : "Elektronski naslov",
    "Instant messaging" : "Hipno sporočanje",
    "Phone" : "Telefon",
    "Mobile" : "Mobilni telefon",
    "Work mobile" : "Službeni mobilni telefon",
    "Fax" : "Faks",
    "Fax home" : "Domači faks",
    "Fax work" : "Službeni faks",
    "Pager" : "Pozivnik",
    "Voice" : "Glas",
    "Car" : "Avto",
    "Work pager" : "Službeni pager",
    "Social network" : "Družbeno omrežje",
    "Relationship" : "Razmerje",
    "Spouse" : "Partner",
    "Child" : "Otrok",
    "Mother" : "Mati",
    "Father" : "Oče",
    "Parent" : "Starš",
    "Brother" : "Brat",
    "Sister" : "Sestra",
    "Relative" : "Sorodnik",
    "Friend" : "Prijatelj",
    "Colleague" : "kolega",
    "Manager" : "Vodja",
    "Assistant" : "Asistent",
    "Gender" : "Spol",
    "Female" : "Ženska",
    "Male" : "Moški",
    "Details" : "Podrobnosti",
    "Settings" : "Nastavitve"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-app-contacts-3.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/sl.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Stiki",
    "Details" : "Podrobnosti",
    "Download" : "Prejmi",
    "Delete" : "Izbriši",
    "Groups" : "Skupine",
    "New contact" : "Nov stik",
    "Copy link" : "Kopiraj povezavo",
    "Rename" : "Preimenuj",
    "Enabled" : "Omogočeno",
    "Disabled" : "Onemogočeno",
    "Share with users or groups" : "Deli z uporabniki ali skupinami",
    "Import into" : "Uvozi v",
    "First name" : "Ime",
    "Last name" : "Priimek",
    "All contacts" : "Vsi stiki",
    "Nickname" : "Vzdevek",
    "Detailed name" : "Podrobno ime",
    "Additional names" : "Druga imena",
    "Prefix" : "Predpona",
    "Suffix" : "Pripona",
    "Notes" : "Zapiski",
    "Website" : "Spletna stran",
    "Federated Cloud ID" : "ID zveznega oblaka",
    "Home" : "Domači naslov",
    "Work" : "Službeni naslov",
    "Other" : "Drugo",
    "Address" : "Naslov",
    "Post office box" : "Poštni predal",
    "City" : "Mesto",
    "State or province" : "Zvezna država ali provinca",
    "Postal code" : "Poštna številka",
    "Country" : "Država",
    "Birthday" : "Rojstni dan",
    "Anniversary" : "Obletnica",
    "Date of death" : "Datum smrti",
    "Email" : "Elektronski naslov",
    "Instant messaging" : "Hipno sporočanje",
    "Phone" : "Telefon",
    "Mobile" : "Mobilni telefon",
    "Work mobile" : "Službeni mobilni telefon",
    "Fax" : "Faks",
    "Fax home" : "Domači faks",
    "Fax work" : "Službeni faks",
    "Pager" : "Pozivnik",
    "Voice" : "Glas",
    "Car" : "Avto",
    "Work pager" : "Službeni pager",
    "Social network" : "Družbeno omrežje",
    "Relationship" : "Razmerje",
    "Spouse" : "Partner",
    "Child" : "Otrok",
    "Mother" : "Mati",
    "Father" : "Oče",
    "Parent" : "Starš",
    "Brother" : "Brat",
    "Sister" : "Sestra",
    "Relative" : "Sorodnik",
    "Friend" : "Prijatelj",
    "Colleague" : "Znanec",
    "Manager" : "Vodja",
    "Assistant" : "Pomočnik",
    "Gender" : "Spol",
    "Female" : "Ženski",
    "Male" : "Moški"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
